@@ -1,23 +1,24 @@
 # following upgrade request 070122
 
-   if(!exists("Sys.setenv", envir = baseenv()))
+if(!exists("Sys.setenv", envir = baseenv()))
      Sys.setenv <- Sys.putenv
-   .rgdal_old.PROJ_LIB <- NULL
-   .rgdal_old.GDAL_DATA <- NULL
+.RGDAL_CACHE <- new.env(FALSE, parent=globalenv())
+assign(".rgdal_old.PROJ_LIB", "", envir=.RGDAL_CACHE)
+assign(".rgdal_old.GDAL_DATA", "", envir=.RGDAL_CACHE)
 
 #.First.lib <- function(lib, pkg) {
 .onLoad <- function(lib, pkg) {
   require(methods, quietly = TRUE, warn.conflicts = FALSE)
   require("sp")
-  .rgdal_old.PROJ_LIB <- Sys.getenv("PROJ_LIB")
-  .rgdal_old.GDAL_DATA <- Sys.getenv("GDAL_DATA")
+  assign(".rgdal_old.PROJ_LIB", Sys.getenv("PROJ_LIB"), envir=.RGDAL_CACHE)
+  assign(".rgdal_old.GDAL_DATA", Sys.getenv("GDAL_DATA"), envir=.RGDAL_CACHE)
+  assign(".rgdal_old.NEEDED", FALSE, envir=.RGDAL_CACHE)
   if (file.exists(system.file("proj/proj_def.dat", package = "rgdal")[1])) {
     Sys.setenv("PROJ_LIB"=system.file("proj", package = "rgdal")[1])
     Sys.setenv("GDAL_DATA"=system.file("gdal", package = "rgdal")[1])
-    .zzz_xxx <- paste(.rgdal_old.PROJ_LIB, .rgdal_old.GDAL_DATA)
-    rm(.zzz_xxx)
+    assign(".rgdal_old.NEEDED", TRUE, envir=.RGDAL_CACHE)
   } else if (.Platform$OS.type == "windows") {
-    .rgdal_OSGeo4W <- Sys.getenv("OSGEO4W_ROOT")
+    assign(".rgdal_OSGeo4W", Sys.getenv("OSGEO4W_ROOT"), envir=.RGDAL_CACHE)
   }
 
   library.dynam('rgdal', pkg, lib)
@@ -39,7 +40,9 @@
 
 #.Last.lib <- function(lib, pkg) {
 .onUnload <- function(libpath) {
-    Sys.setenv("PROJ_LIB"=.rgdal_old.PROJ_LIB)
-    Sys.setenv("GDAL_DATA"=.rgdal_old.GDAL_DATA)
+  if (get(".rgdal_old.NEEDED", envir=.RGDAL_CACHE)) {
+    Sys.setenv("PROJ_LIB"=get(".rgdal_old.PROJ_LIB", envir=.RGDAL_CACHE))
+    Sys.setenv("GDAL_DATA"=get(".rgdal_old.GDAL_DATA", envir=.RGDAL_CACHE))
+  }
 }
 
